package com.zehong.web.service.impl;

import com.zehong.web.mapper.TReportVehicleLocationMapper;
import com.zehong.web.model.entity.TReportVehicleLocation;
import com.zehong.web.service.ITReportVehicleLocationService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 车辆上报位置信息Service业务层处理
 * 
 * @author zehong
 * @date 2024-08-21
 */
@Service
public class TReportVehicleLocationServiceImpl implements ITReportVehicleLocationService
{
    @Resource
    private TReportVehicleLocationMapper tReportVehicleLocationMapper;

    /**
     * 查询车辆上报位置信息
     * 
     * @param locationId 车辆上报位置信息ID
     * @return 车辆上报位置信息
     */
    @Override
    public TReportVehicleLocation selectTReportVehicleLocationById(Long locationId)
    {
        return tReportVehicleLocationMapper.selectTReportVehicleLocationById(locationId);
    }

    /**
     * 查询车辆上报位置信息列表
     * 
     * @param tReportVehicleLocation 车辆上报位置信息
     * @return 车辆上报位置信息
     */
    @Override
    public List<TReportVehicleLocation> selectTReportVehicleLocationList(TReportVehicleLocation tReportVehicleLocation)
    {
        return tReportVehicleLocationMapper.selectTReportVehicleLocationList(tReportVehicleLocation);
    }

    /**
     * 新增车辆上报位置信息
     * 
     * @param tReportVehicleLocation 车辆上报位置信息
     * @return 结果
     */
    @Override
    public int insertTReportVehicleLocation(TReportVehicleLocation tReportVehicleLocation)
    {
        return tReportVehicleLocationMapper.insertTReportVehicleLocation(tReportVehicleLocation);
    }

    /**
     * 修改车辆上报位置信息
     * 
     * @param tReportVehicleLocation 车辆上报位置信息
     * @return 结果
     */
    @Override
    public int updateTReportVehicleLocation(TReportVehicleLocation tReportVehicleLocation)
    {
        return tReportVehicleLocationMapper.updateTReportVehicleLocation(tReportVehicleLocation);
    }

    /**
     * 批量删除车辆上报位置信息
     * 
     * @param locationIds 需要删除的车辆上报位置信息ID
     * @return 结果
     */
    @Override
    public int deleteTReportVehicleLocationByIds(Long[] locationIds)
    {
        return tReportVehicleLocationMapper.deleteTReportVehicleLocationByIds(locationIds);
    }

    /**
     * 删除车辆上报位置信息信息
     * 
     * @param locationId 车辆上报位置信息ID
     * @return 结果
     */
    @Override
    public int deleteTReportVehicleLocationById(Long locationId)
    {
        return tReportVehicleLocationMapper.deleteTReportVehicleLocationById(locationId);
    }

    /**
     * 批量新增车辆位置信息
     * @param list
     * @return
     */
    @Transactional(rollbackFor = Exception.class)
    public int batchInsertReportVehicleLocationInfo(List<TReportVehicleLocation> list){
        return tReportVehicleLocationMapper.batchInsertReportVehicleLocationInfo(list);
    }
}
